@@ -199,7 +199,11 @@ class SencyberLogger:
     """
     Defines a Logger using default python logger and send the logs to specific server
     """
-    def __init__(self, receiver_address='0.0.0.0', receiver_port=10080, title='default', auto_interval=1200):
+    def __init__(self, receiver_address='0.0.0.0',
+                 receiver_port=10080,
+                 title='default',
+                 auto_interval=1200,
+                 level=logging.DEBUG):
         self.receiver_address = receiver_address
         self.receiver_port = receiver_port
         self.title = title
@@ -213,7 +217,7 @@ class SencyberLogger:
         LOG_FORMAT = "%(asctime)s [%(levelname)s]: %(message)s @ [%(module)s-%(lineno)s]"
         logging.basicConfig(
             filename=f"{self.file_name}.log",
-            level=logging.DEBUG,
+            level=level,
             format=LOG_FORMAT,
         )
 
@@ -268,14 +272,26 @@ class SencyberLogger:
                 s_header = struct.pack('i', len(header_bytes))
 
                 client.send(s_header)
-                print(s_header)
                 client.send(header_bytes)
-                print(header_bytes)
+
+                dat = client.recv(1)
+
+                if dat != b"\x55":
+                    raise Exception
+
                 for i in range(len(data) // 4096 + 1):
                     if (i + 1) * 4096 < len(data):
                         client.send(data[4096 * i: 4096 * (i + 1)])
+                        dat = client.recv(1)
+                        if dat != b"\x55":
+                            logging.error("Protocol Error!")
+                            raise Exception
                     else:
                         client.send(data[4096 * i: len(data)])
+                        dat = client.recv(1)
+                        if dat != b"\x55":
+                            logging.error("Protocol Error!")
+                            raise Exception
                 client.close()
             else:
                 logging.error(f"{self.receiver_address}:{self.receiver_port} is not a proper log server.")
@@ -355,7 +371,6 @@ class SencyberLoggerReceiver:
                 conn.settimeout(10)
                 s_header = conn.recv(4)
                 s_header = struct.unpack('i', s_header)[0]
-
                 b_header = conn.recv(s_header)
 
                 json_header = b_header.decode('utf-8')
@@ -370,11 +385,14 @@ class SencyberLoggerReceiver:
                 res = b""
                 size = 0
 
+                conn.send(b"\x55")
+
                 while size < file_size:
                     data = conn.recv(4096)
                     if len(data) == 0:
                         logging.debug(f"Abort By {size} / {file_size}")
                         raise Exception
+                    conn.send(b"\x55")
                     size += len(data)
                     res += data
 
